==> yass-1.09.tar.gz: yass-1.09/proba.h <==
/*
 *  YASS 1.09
 *  Copyright (C) 2004,2005
 *  YASS Team
 *  Laurent Noe, Gregory Kucherov, Mikhail Roytberg, Christophe Valmir, Steven Corroy
 *  yass@loria.fr
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This software contains code derived from the GNU libavl library.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */
#ifndef __PROBA_H_
#define __PROBA_H_

int statistical_bound_of_waiting_time1(double p, int k, double alpha);
int statistical_bound_of_waiting_time2(double p, int k, double alpha);
double *randomwalk_probability_of_pos1(double pI, int L);
double *randomwalk_probability_of_pos2(double pI, int L);
double *randomwalk_probability_of_pos3(double pI, int L);
int statistical_bound_of_randomwalk1(double pI, int L, double alpha);
int statistical_bound_of_randomwalk2(double pI, int L, double alpha);
double Evalue(double K, double Lambda, int query_size, int text_size,
	      int score);
int MinScore(double K, double Lambda, int query_size, int text_size,
	     double MaxEvalue);
double BitScore(double K, double Lambda, int score);
double P_mutation_bias(int freq[]);


#define NBRE_LETTRE 4
#define NBRE_SCORE  4
#define SENSIBILITY_LAMBDA 1e-10
#define NBLOOPS_K 20		/* coorespond au nombre de fois que l'on boucle pour representer l'infini default:20 */
#define DELTA_K 1

void computeProbability(double *p_probabilite[]
			/*out tableau de NBRE_SCORE */ ,
			int *p_score[] /*out tableau de NBRE_SCORE */ ,
			int *p_nbreScore /*out */ );

double computeLambda(double *proba, int *score, int nbrScore);

double computeK(double *proba,	/* Probabilite match/transition/transvertion/Other */
		int *score, 
		int nbrScore, 
		double lambda);


#endif

==> yass-1.10.tar.gz: yass-1.10/proba.h <==
/*
 *  YASS 1.10
 *  Copyright (C) 2004,2005
 *  YASS Team
 *  Laurent Noe, Gregory Kucherov, Mikhail Roytberg, 
 *  Christophe Valmir, Steven Corroy
 *
 *  noe|<A>|lifl.fr
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This software contains code derived from the GNU libavl library.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef __PROBA_H_
#define __PROBA_H_

int statistical_bound_of_waiting_time1(double p, int k, double alpha);
int statistical_bound_of_waiting_time2(double p, int k, double alpha);
double *randomwalk_probability_of_pos1(double pI, int L);
double *randomwalk_probability_of_pos2(double pI, int L);
double *randomwalk_probability_of_pos3(double pI, int L);
int statistical_bound_of_randomwalk1(double pI, int L, double alpha);
int statistical_bound_of_randomwalk2(double pI, int L, double alpha);
double Evalue(double K, double Lambda, int query_size, int text_size,
	      int score);
int MinScore(double K, double Lambda, int query_size, int text_size,
	     double MaxEvalue);
double BitScore(double K, double Lambda, int score);
double P_mutation_bias(int freq[]);


double * computeProbability(); 

double computeLambda(/* in */double * proba);

double computeK(/* in */double * proba ,double lambda);

double entropyTriplet(int * count /* [4^3]*/);


#endif
